@@ -19,12 +19,14 @@ extern void child_sendw(const wchar *, uint len);
 extern void child_resize(struct winsize * winp);
 extern bool child_is_alive(void);
 extern bool child_is_parent(void);
+extern char * procres(int pid, char * res);
 extern wchar * grandchild_process_list(void);
 extern char * child_tty(void);
+extern uchar * child_termios_chars(void);
 extern char * foreground_prog(void);  // to be free()d
 extern void user_command(wstring commands, int n);
 extern wstring child_conv_path(wstring, bool adjust_dir);
-extern void child_fork(int argc, char * argv[], int moni, bool config_size, bool in_cwd);
+extern void child_fork(int argc, char * argv[], int moni, bool config_size, bool in_cwd, bool in_tabs);
 extern void child_set_fork_dir(char *);
 extern void setenvi(char * env, int val);
 extern void child_launch(int n, int argc, char * argv[], int moni);
