@@ -69,7 +69,8 @@ shell_exec_thread(void *data)
   cygwin_internal(CW_SYNC_WINENV);
 #endif
 
-  if ((INT_PTR)ShellExecuteW(wnd, 0, wpath, 0, 0, SW_SHOWNORMAL) <= 32) {
+  SetLastError(ERROR_PATH_NOT_FOUND);  // in case !*wpath
+  if (!*wpath || (INT_PTR)ShellExecuteW(wnd, 0, wpath, 0, 0, SW_SHOWNORMAL) <= 32) {
     uint error = GetLastError();
     if (error != ERROR_CANCELLED) {
       int msglen = 1024;
@@ -126,22 +127,6 @@ ispathprefix(string pref, string path)
   return false;
 }
 
-static bool
-ispathprefixw(wstring pref, wstring path)
-{
-  if (*pref == '/')
-    pref++;
-  if (*path == '/')
-    path++;
-  int len = wcslen(pref);
-  if (0 == wcsncmp(pref, path, len)) {
-    path += len;
-    if (!*path || *path == '/')
-      return true;
-  }
-  return false;
-}
-
 static char * wsl_conf_mnt = 0;
 static struct {
   char * dev_fs;
@@ -329,46 +314,6 @@ wslmntmapped(void)
   return wsl_conf_mnt || wsl_fstab;
 }
 
-static char *
-unwslpath(wchar * wpath)
-{
-  char * res = null;
-  if (wslmntmapped()) {
-    char * wslpath = cs__wcstoutf(wpath);
-    if (wsl_conf_mnt && ispathprefix(wsl_conf_mnt, wslpath))
-      res = asform("/cygdrive%s", &wslpath[strlen(wsl_conf_mnt)]);
-    else
-      for (int i = 0; i < wsl_fstab_len; i++) {
-#if defined(debug_wslpath) && debug_wslpath > 2
-        printf("unwslpath <%s> <%s> (%s)\n", wslpath, wsl_fstab[i].mount_point, wsl_fstab[i].dev_fs);
-#endif
-        if (ispathprefix(wsl_fstab[i].mount_point, wslpath)) {
-          if (wsl_fstab[i].dev_fs[1] == ':') {
-            res = asform(
-#if defined(__MSYS__) || defined(__MINGW32)
-#else
-                         "/cygdrive"
-#endif
-                         "/%c%s%s", 
-                         tolower((int)wsl_fstab[i].dev_fs[0]), 
-                         &wsl_fstab[i].dev_fs[2], 
-                         &wslpath[strlen(wsl_fstab[i].mount_point)]);
-            break;
-          }
-          else {  // handle UNC path mount
-            res = asform("%s%s", wsl_fstab[i].dev_fs, wslpath + strlen(wsl_fstab[i].mount_point));
-            for (char * r = res; *r; r++)
-              // cygwin path conversion fails on backslash UNC paths
-              if (*r == '\\')
-                *r = '/';
-          }
-        }
-      }
-    free(wslpath);
-  }
-  return res;
-}
-
 static char *
 wslpath(char * path)
 {
@@ -429,6 +374,64 @@ wslpath(char * path)
   return res;
 }
 
+#ifdef pathname_conversion_here
+
+static bool
+ispathprefixw(wstring pref, wstring path)
+{
+  if (*pref == '/')
+    pref++;
+  if (*path == '/')
+    path++;
+  int len = wcslen(pref);
+  if (0 == wcsncmp(pref, path, len)) {
+    path += len;
+    if (!*path || *path == '/')
+      return true;
+  }
+  return false;
+}
+
+static char *
+unwslpath(wchar * wpath)
+{
+  char * res = null;
+  if (wslmntmapped()) {
+    char * wslpath = cs__wcstoutf(wpath);
+    if (wsl_conf_mnt && ispathprefix(wsl_conf_mnt, wslpath))
+      res = asform("/cygdrive%s", &wslpath[strlen(wsl_conf_mnt)]);
+    else
+      for (int i = 0; i < wsl_fstab_len; i++) {
+#if defined(debug_wslpath) && debug_wslpath > 2
+        printf("unwslpath <%s> <%s> (%s)\n", wslpath, wsl_fstab[i].mount_point, wsl_fstab[i].dev_fs);
+#endif
+        if (ispathprefix(wsl_fstab[i].mount_point, wslpath)) {
+          if (wsl_fstab[i].dev_fs[1] == ':') {
+            res = asform(
+#if defined(__MSYS__) || defined(__MINGW32)
+#else
+                         "/cygdrive"
+#endif
+                         "/%c%s%s", 
+                         tolower((int)wsl_fstab[i].dev_fs[0]), 
+                         &wsl_fstab[i].dev_fs[2], 
+                         &wslpath[strlen(wsl_fstab[i].mount_point)]);
+            break;
+          }
+          else {  // handle UNC path mount
+            res = asform("%s%s", wsl_fstab[i].dev_fs, wslpath + strlen(wsl_fstab[i].mount_point));
+            for (char * r = res; *r; r++)
+              // cygwin path conversion fails on backslash UNC paths
+              if (*r == '\\')
+                *r = '/';
+          }
+        }
+      }
+    free(wslpath);
+  }
+  return res;
+}
+
 wchar *
 dewsl(wchar * wpath)
 {
@@ -495,6 +498,8 @@ dewsl(wchar * wpath)
   return wpath;
 }
 
+#endif
+
 #if CYGWIN_VERSION_API_MINOR < 206
 #define wcsncasecmp wcsncmp
 #define wmemcpy(t, s, n)	memcpy(t, s, 2 * n)
@@ -531,13 +536,23 @@ win_open(wstring wpath, bool adjust_dir)
   wbuf[wl] = 0;
   delete(wpath);
 
+  // guard file opening against foreign network access
+  char * buf = cs__wcstoutf(wbuf);
+  char * gbuf = guardpath(buf, 4);
+  free(buf);
+  if (!gbuf)
+    return;
+
   wchar *p = wbuf;
   while (iswalpha(*p)) p++;
   if (*p == ':' || *wbuf == '\\' || !wcsncasecmp(W("www."), wbuf, 4)) {
     // Looks like it's a Windows path or URI
+    free(gbuf);
     shell_exec(wbuf); // frees wbuf
   }
   else {
+#ifdef pathname_conversion_here
+#warning now deprecated; handled via guardpath
     // Need to convert POSIX path to Windows first
     if (support_wsl) {
       // First, we need to replicate some of the handling of relative paths
@@ -560,6 +575,11 @@ win_open(wstring wpath, bool adjust_dir)
       wbuf = dewsl(wbuf);
     }
     wstring conv_wpath = child_conv_path(wbuf, adjust_dir);
+#else
+    (void)adjust_dir;
+    wchar *conv_wpath = path_posix_to_win_w(gbuf);
+    free(gbuf);
+#endif
 #ifdef debug_wslpath
     printf("win_open <%ls> <%ls>\n", wbuf, conv_wpath);
 #endif
